/***
*stdio.h - definitions/declarations for standard I/O routines
*
*
*Purpose:
*   This file contains definitions and declarations for the
*   level 2 I/O ("standard I/O") routines, including the structures
*   used by the routines and some of the associated values and macros.
*   [ANSI/System V]
*
*******************************************************************************/


#ifndef _SIZE_T_DEFINED
typedef unsigned int size_t;
#define _SIZE_T_DEFINED
#endif

#ifndef _VA_LIST_DEFINED
typedef char *va_list;
#define _VA_LIST_DEFINED
#endif

#define  BUFSIZ  512
#define  _NFILE  20
#define  EOF     (-1)

#ifndef _FILE_DEFINED
#define  FILE    struct _iobuf
#define _FILE_DEFINED
#endif

#define  P_tmpdir "\\TMP"

/* L_tmpnam size:  size of P_tmpdir + 1 (for the "\") +6 (for the temp
 * number string) + 1 (for the null terminator)
 */
#define  L_tmpnam sizeof(P_tmpdir)+8

#define  SEEK_CUR 1
#define  SEEK_END 2
#define  SEEK_SET 0

#define  SYS_OPEN 20
#define  TMP_MAX  32767

#if (!defined(M_I86CM) && !defined(M_I86LM))
#define  NULL    0
#else
#define  NULL    0L
#endif

#ifndef _IOB_DEFINED
extern FILE {
    char *_ptr;
    int   _cnt;
    char *_base;
    char  _flag;
    char  _file;
#ifndef NO_EXT_KEYS /* extended keywords are enabled */
    } cdecl _iob[];
#else           /* extended keywords not enabled */
    } _iob[];
#endif  /* NO_EXT_KEYS */
#define _IOB_DEFINED
#endif  /* _IOB_DEFINED */

#define  stdin   (&_iob[0])
#define  stdout  (&_iob[1])
#define  stderr  (&_iob[2])
#define  stdaux  (&_iob[3])
#define  stdprn  (&_iob[4])

#define  _IOREAD    0x01
#define  _IOWRT     0x02

#define  _IOFBF     0x0
#define  _IOLBF     0x40
#define  _IONBF     0x04

#define  _IOMYBUF   0x08
#define  _IOEOF     0x10
#define  _IOERR     0x20
#define  _IOSTRG    0x40
#define  _IORW      0x80

#define  getc(f)    (--(f)->_cnt >= 0 ? 0xff & *(f)->_ptr++ : _filbuf(f))
#define  putc(c,f)  (--(f)->_cnt >= 0 ? 0xff & (*(f)->_ptr++ = (char)(c)) : \
             _flsbuf((c),(f)))

#define  getchar()   getc(stdin)
#define  putchar(c)  putc((c),stdout)

#define  feof(f)     ((f)->_flag & _IOEOF)
#define  ferror(f)   ((f)->_flag & _IOERR)
#define  fileno(f)   ((f)->_file)

/* function declarations for those who want strong type checking
 * on arguments to library function calls
 */

#ifdef LINT_ARGS    /* argument checking enabled */

#ifndef NO_EXT_KEYS /* extended keywords are enabled */
int cdecl _filbuf(FILE *);
int cdecl _flsbuf(int, FILE *);
void cdecl clearerr(FILE *);
int cdecl fclose(FILE *);
int cdecl fcloseall(void);
FILE * cdecl fdopen(int, char *);
int cdecl fflush(FILE *);
int cdecl fgetc(FILE *);
int cdecl fgetchar(void);
char * cdecl fgets(char *, int, FILE *);
int cdecl flushall(void);
FILE * cdecl fopen(const char *, const char *);
int cdecl fprintf(FILE *, const char *, ...);
int cdecl fputc(int, FILE *);
int cdecl fputchar(int);
int cdecl fputs(const char *, FILE *);
size_t cdecl fread(void *, size_t, size_t, FILE *);
FILE * cdecl freopen(const char *, const char *, FILE *);
int cdecl fscanf(FILE *, const char *, ...);
int cdecl fseek(FILE *, long, int);
long cdecl ftell(FILE *);
size_t cdecl fwrite(const void *, size_t, size_t, FILE *);
char * cdecl gets(char *);
int cdecl getw(FILE *);
void cdecl perror(const char *);
int cdecl printf(const char *, ...);
int cdecl puts(const char *);
int cdecl putw(int, FILE *);
int cdecl remove(const char *);
int cdecl rename(const char *, const char *);
void cdecl rewind(FILE *);
int cdecl rmtmp(void);
int cdecl scanf(const char *, ...);
void cdecl setbuf(FILE *, char *);
int cdecl setvbuf(FILE *, char *, int, size_t);
int cdecl sprintf(char *, const char *, ...);
int cdecl sscanf(const char *, const char *, ...);
char * cdecl tempnam(char *, char *);
FILE * cdecl tmpfile(void);
char * cdecl tmpnam(char *);
int cdecl ungetc(int, FILE *);
int cdecl unlink(char *);
int cdecl vfprintf(FILE *, const char *, va_list);
int cdecl vprintf(const char *, va_list);
int cdecl vsprintf(char *, const char *, va_list);
#else           /* extended keywords not enabled */
int _filbuf(FILE *);
int _flsbuf(int, FILE *);
void clearerr(FILE *);
int fclose(FILE *);
int fcloseall(void);
FILE *fdopen(int, char *);
int fflush(FILE *);
int fgetc(FILE *);
int fgetchar(void);
char *fgets(char *, int, FILE *);
int flushall(void);
FILE *fopen(const char *, const char *);
int fprintf(FILE *, const char *, ...);
int fputc(int, FILE *);
int fputchar(int);
int fputs(const char *, FILE *);
size_t fread(void *, size_t, size_t, FILE *);
FILE *freopen(const char *, const char *, FILE *);
int fscanf(FILE *, const char *, ...);
int fseek(FILE *, long, int);
long ftell(FILE *);
size_t fwrite(const void *, size_t, size_t, FILE *);
char *gets(char *);
int getw(FILE *);
void perror(const char *);
int printf(const char *, ...);
int puts(char *);
int putw(int, FILE *);
int remove(const char *);
int rename(const char *, const char *);
void rewind(FILE *);
int rmtmp(void);
int scanf(const char *, ...);
void setbuf(FILE *, char *);
int setvbuf(FILE *, char *, int, size_t);
int sprintf(char *, const char *, ...);
int sscanf(char *, char *, ...);
char *tempnam(char *, char *);
FILE *tmpfile(void);
char *tmpnam(char *);
int ungetc(int, FILE *);
int unlink(char *);
int vfprintf(FILE *, const char *, va_list);
int vprintf(const char *, va_list);
int vsprintf(char *, const char *, va_list);
#endif  /* NO_EXT_KEYS */

#else           /* argument checking not enabled */

#ifndef NO_EXT_KEYS /* extended keywords are enabled */
int cdecl _filbuf();
int cdecl _flsbuf();
void cdecl clearerr();
int cdecl fclose();
int cdecl fcloseall();
FILE * cdecl fdopen();
int cdecl fflush();
int cdecl fgetc();
int cdecl fgetchar();
char * cdecl fgets();
int cdecl flushall();
FILE * cdecl fopen();
int cdecl fprintf();
int cdecl fputc();
int cdecl fputchar();
int cdecl fputs();
size_t cdecl fread();
FILE * cdecl freopen();
int cdecl fscanf();
int cdecl fseek();
long cdecl ftell();
size_t cdecl fwrite();
char * cdecl gets();
int cdecl getw();
void cdecl perror();
int cdecl printf();
int cdecl puts();
int cdecl putw();
int cdecl remove();
int cdecl rename();
void cdecl rewind();
int cdecl rmtmp();
int cdecl scanf();
void cdecl setbuf();
int cdecl setvbuf();
int cdecl sprintf();
int cdecl sscanf();
char * cdecl tempnam();
FILE * cdecl tmpfile();
char * cdecl tmpnam();
int cdecl ungetc();
int cdecl unlink();
int cdecl vfprintf();
int cdecl vprintf();
int cdecl vsprintf();
#else           /* extended keywords not enabled */
void clearerr();
FILE *fdopen();
char *fgets();
FILE *fopen();
FILE *freopen();
long ftell();
char *gets();
void perror();
void rewind();
void setbuf();
char *tempnam();
FILE *tmpfile();
char *tmpnam();
#endif  /* NO_EXT_KEYS */

#endif  /* LINT_ARGS */
